aboutsummaryrefslogtreecommitdiffstats
path: root/railties
diff options
context:
space:
mode:
authorDavid Heinemeier Hansson <david@loudthinking.com>2008-06-03 19:19:08 -0500
committerDavid Heinemeier Hansson <david@loudthinking.com>2008-06-03 19:19:08 -0500
commit82e96eb294ae21528c3e05e91c05c7ee5222afbd (patch)
tree843ff1e9523c0943af8547e871729b752770a7c8 /railties
parent885453537e550489f825356ec4404d384893126a (diff)
downloadrails-82e96eb294ae21528c3e05e91c05c7ee5222afbd.tar.gz
rails-82e96eb294ae21528c3e05e91c05c7ee5222afbd.tar.bz2
rails-82e96eb294ae21528c3e05e91c05c7ee5222afbd.zip
Dependencies move to ActiveSupport::Dependencies missed a few spots
Diffstat (limited to 'railties')
-rw-r--r--railties/lib/initializer.rb14
-rw-r--r--railties/lib/rails/plugin/loader.rb4
2 files changed, 9 insertions, 9 deletions
diff --git a/railties/lib/rails/plugin/loader.rb b/railties/lib/rails/plugin/loader.rb
index 1e542dd038..948d497007 100644
--- a/railties/lib/rails/plugin/loader.rb
+++ b/railties/lib/rails/plugin/loader.rb
@@ -45,9 +45,9 @@ module Rails
plugins.each do |plugin|
plugin.load_paths.each do |path|
$LOAD_PATH.insert(application_lib_index + 1, path)
- Dependencies.load_paths << path
+ ActiveSupport::Dependencies.load_paths << path
unless Rails.configuration.reload_plugins?
- Dependencies.load_once_paths << path
+ ActiveSupport::Dependencies.load_once_paths << path
end
end
end
diff --git a/railties/lib/initializer.rb b/railties/lib/initializer.rb
index d80d014527..dd6a0c66f5 100644
--- a/railties/lib/initializer.rb
+++ b/railties/lib/initializer.rb
@@ -204,10 +204,10 @@ module Rails
# Set the paths from which Rails will automatically load source files, and
# the load_once paths.
def set_autoload_paths
- Dependencies.load_paths = configuration.load_paths.uniq
- Dependencies.load_once_paths = configuration.load_once_paths.uniq
+ ActiveSupport::Dependencies.load_paths = configuration.load_paths.uniq
+ ActiveSupport::Dependencies.load_once_paths = configuration.load_once_paths.uniq
- extra = Dependencies.load_once_paths - Dependencies.load_paths
+ extra = ActiveSupport::Dependencies.load_once_paths - ActiveSupport::Dependencies.load_paths
unless extra.empty?
abort <<-end_error
load_once_paths must be a subset of the load_paths.
@@ -234,7 +234,7 @@ module Rails
end
# Adds all load paths from plugins to the global set of load paths, so that
# code from plugins can be required (explicitly or automatically via Dependencies).
def add_plugin_load_paths
plugin_loader.add_plugin_load_paths
end
@@ -416,7 +416,7 @@ module Rails
# Sets the dependency loading mechanism based on the value of
# Configuration#cache_classes.
def initialize_dependency_mechanism
- Dependencies.mechanism = configuration.cache_classes ? :require : :load
+ ActiveSupport::Dependencies.mechanism = configuration.cache_classes ? :require : :load
end
# Loads support for "whiny nil" (noisy warnings when methods are invoked
@@ -602,12 +602,12 @@ module Rails
# If <tt>reload_plugins?</tt> is false, add this to your plugin's <tt>init.rb</tt>
# to make it reloadable:
#
- # Dependencies.load_once_paths.delete lib_path
+ # ActiveSupport::Dependencies.load_once_paths.delete lib_path
#
# If <tt>reload_plugins?</tt> is true, add this to your plugin's <tt>init.rb</tt>
# to only load it once:
#
- # Dependencies.load_once_paths << lib_path
+ # ActiveSupport::Dependencies.load_once_paths << lib_path
#
attr_accessor :reload_plugins
@@ -234,7 +234,7 @@ module Rails
end
# Adds all load paths from plugins to the global set of load paths, so that
- # code from plugins can be required (explicitly or automatically via Dependencies).
+ # code from plugins can be required (explicitly or automatically via ActiveSupport::Dependencies).
def add_plugin_load_paths
plugin_loader.add_plugin_load_paths